package animation;

import java.awt.image.BufferedImage;
import java.io.Serializable;

/**
 * This class represents an animation
 * @author Frank Bruns
 *
 */
public class Animation implements Serializable
{
	private BufferedImage[] images = null;
	private long duration = -1;
	private String name = "no name yet";
	private boolean running = false;
	
	/**
	 * Creates a new animation
	 * @param images animation images
	 * @param name animation reference name
	 * @param dur duration of the animation
	 */
	public Animation(BufferedImage[] images, String name, long dur)
	{
		this.images = images;
		this.name = name;
		this.duration = dur;
	}
	
	/**
	 * Creates a new animation with infinite duration. Such animations only
	 * get eliminated from the animation schedule by clearing the schedule
	 * with the scheduler's clear() method.
	 * @param images animation images
	 * @param name animation reference name
	 */
	public Animation(BufferedImage[] images, String name)
	{
		this.images = images;
		this.name = name;
	}
	
	/**
	 * Returns the image sequence that forms the animation
	 * @return animation images
	 */
	public BufferedImage[] getImages()
	{
		return this.images;
	}
	
	/**
	 * Returns the duration (in miliseconds) of the animation. A duration of -1
	 * means infinite duration and has to be processed as such.
	 * @return duration of the animation, -1 is infinite duration
	 */
	public long getDuration()
	{
		return this.duration;
	}
	
	/**
	 * Determines whether the animation has infinite duration or not.
	 * @return has infinite duration? --> true=yes, false=no
	 */
	public boolean isInfinite()
	{
		if(this.duration == -1) return true;
		else return false;
	}
	
	/**
	 * Determines whether this animation is currently running
	 * @return is currently running? --> true=yes, false=no
	 */
	public boolean isRunning()
	{
		return this.running;
	}
	
	/**
	 * Sets if the animation is currently running.
	 * @param running is running? --> true=yes, false=no
	 */
	public void setRunning(boolean running)
	{
		this.running = running;
	}
	
	/**
	 * Returns the reference name that has been specified for the
	 * animation
	 * @return animation reference name
	 */
	public String getName()
	{
		return this.name;
	}
}
