package animation;

import java.awt.image.BufferedImage;
import java.io.Serializable;
import java.util.HashMap;


/**
 * This class is used to manage the animation sequences of a game object
 * @author Frank Bruns
 *
 */
public class AnimationPool implements Serializable
{	
	private HashMap<String,BufferedImage[]> sequencePool = null;
	
	/**
	 * Creates a new empty pool of animation sequences. Add animation
	 * sequences by using the add() method of this class.
	 *
	 */
	public AnimationPool()
	{
		this.sequencePool = new HashMap<String, BufferedImage[]>();
	}
	
	/**
	 * Returns the animation sequence that refers to the specified reference name
	 * @param name reference name of the animation
	 * @return animation sequence refering to the specified name
	 */
	public BufferedImage[] getAnimSequence(String name)
	{
		return this.sequencePool.get(name);
	}
	
	/**
	 * Determines, if the animatio pool contains the animation
	 * identified by the specified name
	 * @param name name of the animation
	 * @return contain animation? --> true=yes, false=no
	 */
	public boolean containsAnim(String name)
	{
		return this.sequencePool.containsKey(name);
	}
	
	/**
	 * Adds an animation to the animation manager
	 * @param name name refering to the animation
	 * @param images images that form the animation
	 */
	public void add(String name, BufferedImage[] images)
	{
		this.sequencePool.put(name,images);
	}
	
	/**
	 * Removes an animation sequence from the animation pool
	 * @param name name of the animation to remove
	 */
	public void remove(String name)
	{
		this.sequencePool.remove(name);
	}
}
