package editor.gui;

import java.awt.Dimension;
import java.awt.EventQueue;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Vector;

import javax.swing.DefaultComboBoxModel;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.ListModel;
import javax.swing.WindowConstants;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

import org.jdesktop.layout.GroupLayout;
import org.jdesktop.layout.LayoutStyle;

import editor.model.Hotspot;


/**
 * Editor panel for interactive hotspots
 * @author Frank Bruns
 *
 */
public class HotspotsPanel extends JPanel
{
	private JList listHotspots;
	private JLabel labelHotspotName;
	private JTextField textHotspotBshName;
	private JTextField textPosX;
	private JTextField textPosY;
	private JButton buttonAddHotspot;
	private JTextField textHeight;
	private JLabel labelWidth;
	private JLabel labelHeight;
	private JTextField textWidth;
	private JLabel labelY;
	private JLabel labelX;
	private JLabel labelPosXY;
	private JLabel labelHotspotBshName;
	private JTextField textHotspotName;
	
	private Vector<Hotspot> hotspots = null;

	/**
	* Auto-generated main method to display this 
	* JPanel inside a new JFrame.
	*/
	public static void main(String[] args) {
		JFrame frame = new JFrame();
		frame.getContentPane().add(new ExitsPanel());
		frame.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
		frame.pack();
		frame.setVisible(true);
	}
	
	public HotspotsPanel() {
		super();
		initGUI();
		this.hotspots = new Vector<Hotspot>();
	}
	
	private void initGUI() {
		try {
			GroupLayout thisLayout = new GroupLayout((JComponent) this);
			this.setLayout(thisLayout);
			setPreferredSize(new Dimension(400, 300));
			{
				listHotspots = new JList();
				listHotspots.addListSelectionListener(new ListSelectionListener() {
					public void valueChanged(ListSelectionEvent evt) {
						listHotspotsValueChanged(evt);
					}
				});
			}
			{
				textHotspotName = new JTextField();
			}
			{
				labelHotspotName = new JLabel();
				labelHotspotName.setText("Hotspot name:");
			}
			{
				labelHotspotBshName = new JLabel();
				labelHotspotBshName.setText("Hotspot beanshell name:");
			}
			{
				textHotspotBshName = new JTextField();
			}
			{
				labelPosXY = new JLabel();
				labelPosXY.setText("Position:");
			}
			{
				textPosX = new JTextField();
			}
			{
				textPosY = new JTextField();
			}
			{
				labelX = new JLabel();
				labelX.setText("x:");
			}
			{
				labelY = new JLabel();
				labelY.setText("y:");
			}
			{
				labelWidth = new JLabel();
				labelWidth.setText("Width:");
			}
			{
				textWidth = new JTextField();
			}
			{
				labelHeight = new JLabel();
				labelHeight.setText("Height:");
			}
			{
				textHeight = new JTextField();
			}
			{
				buttonAddHotspot = new JButton();
				buttonAddHotspot.setText("Add hotspot");
				buttonAddHotspot.addActionListener(new ActionListener() {
					public void actionPerformed(ActionEvent evt) {
						buttonAddExitActionPerformed(evt);
					}
				});
			}
				thisLayout.setHorizontalGroup(thisLayout.createSequentialGroup()
			    .addContainerGap()
			    .add(thisLayout.createParallelGroup()
			        .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			            .add(labelHotspotName)
			            .add(48))
			        .add(GroupLayout.LEADING, labelHotspotBshName)
			        .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			            .add(labelPosXY)
			            .add(78))
			        .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			            .add(labelWidth)
			            .add(87))
			        .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			            .add(labelHeight)
			            .add(84)))
			    .add(27)
			    .add(thisLayout.createParallelGroup()
			        .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			            .add(textHotspotName, GroupLayout.PREFERRED_SIZE, 101, GroupLayout.PREFERRED_SIZE)
			            .addPreferredGap(LayoutStyle.RELATED))
			        .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			            .add(textHotspotBshName, GroupLayout.PREFERRED_SIZE, 101, GroupLayout.PREFERRED_SIZE)
			            .addPreferredGap(LayoutStyle.RELATED))
			        .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			            .add(labelX)
			            .addPreferredGap(LayoutStyle.RELATED)
			            .add(textPosX, GroupLayout.PREFERRED_SIZE, 27, GroupLayout.PREFERRED_SIZE)
			            .add(12)
			            .add(labelY)
			            .add(12)
			            .add(textPosY, GroupLayout.PREFERRED_SIZE, 26, GroupLayout.PREFERRED_SIZE))
			        .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			            .add(textWidth, GroupLayout.PREFERRED_SIZE, 101, GroupLayout.PREFERRED_SIZE)
			            .addPreferredGap(LayoutStyle.RELATED))
			        .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			            .add(textHeight, GroupLayout.PREFERRED_SIZE, 101, GroupLayout.PREFERRED_SIZE)
			            .addPreferredGap(LayoutStyle.RELATED))
			        .add(GroupLayout.LEADING, buttonAddHotspot, GroupLayout.PREFERRED_SIZE, 104, GroupLayout.PREFERRED_SIZE))
			    .addPreferredGap(LayoutStyle.RELATED)
			    .add(listHotspots, GroupLayout.PREFERRED_SIZE, 121, GroupLayout.PREFERRED_SIZE)
			    .addContainerGap());
				thisLayout.setVerticalGroup(thisLayout.createSequentialGroup()
			    .addContainerGap()
			    .add(thisLayout.createParallelGroup()
			        .add(GroupLayout.LEADING, listHotspots, GroupLayout.PREFERRED_SIZE, 276, GroupLayout.PREFERRED_SIZE)
			        .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			            .add(thisLayout.createParallelGroup()
			                .add(GroupLayout.LEADING, textHotspotName, GroupLayout.PREFERRED_SIZE, 18, GroupLayout.PREFERRED_SIZE)
			                .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			                    .add(labelHotspotName)
			                    .addPreferredGap(LayoutStyle.RELATED)))
			            .addPreferredGap(LayoutStyle.RELATED)
			            .add(thisLayout.createParallelGroup()
			                .add(GroupLayout.BASELINE, textHotspotBshName, GroupLayout.PREFERRED_SIZE, 21, GroupLayout.PREFERRED_SIZE)
			                .add(GroupLayout.BASELINE, labelHotspotBshName))
			            .add(14)
			            .add(thisLayout.createParallelGroup()
			                .add(GroupLayout.BASELINE, textPosX, GroupLayout.PREFERRED_SIZE, 21, GroupLayout.PREFERRED_SIZE)
			                .add(GroupLayout.BASELINE, labelPosXY)
			                .add(GroupLayout.BASELINE, textPosY, GroupLayout.PREFERRED_SIZE, 21, GroupLayout.PREFERRED_SIZE)
			                .add(GroupLayout.BASELINE, labelX)
			                .add(GroupLayout.BASELINE, labelY))
			            .addPreferredGap(LayoutStyle.RELATED)
			            .add(thisLayout.createParallelGroup()
			                .add(GroupLayout.BASELINE, textWidth, GroupLayout.PREFERRED_SIZE, 22, GroupLayout.PREFERRED_SIZE)
			                .add(GroupLayout.BASELINE, labelWidth))
			            .addPreferredGap(LayoutStyle.RELATED)
			            .add(thisLayout.createParallelGroup()
			                .add(GroupLayout.LEADING, textHeight, GroupLayout.PREFERRED_SIZE, 23, GroupLayout.PREFERRED_SIZE)
			                .add(GroupLayout.LEADING, thisLayout.createSequentialGroup()
			                    .add(9)
			                    .add(labelHeight)))
			            .add(117)
			            .add(buttonAddHotspot)))
			    .addContainerGap());
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * Returns a vector containing the interactive hotspots created with the editor
	 * @return vector with interactive hotspots
	 */
	public Vector<Hotspot> getHotspotList()
	{
		return this.hotspots;
	}
	
	/**
	 * Adds a new exit to the list
	 * @param evt
	 */
	private void buttonAddExitActionPerformed(ActionEvent evt) 
	{
		Hotspot hotspot = new Hotspot(this.textHotspotName.getText(),
				this.textHotspotBshName.getText(),
				this.textPosX.getText(),
				this.textPosY.getText(),
				this.textWidth.getText(),
				this.textHeight.getText());
		
		// add hotspot to the list of exits
		this.hotspots.add(hotspot);
		
		// create a data model with the hotspot names for displaying in
		// the JList
		String[] model = new String[this.hotspots.size()];
		for(int i=0; i<this.hotspots.size(); i++)
		{
			model[i] = this.hotspots.get(i).getName();
		}
		ListModel listHotspotModel = new DefaultComboBoxModel(model);
		this.listHotspots.setModel(listHotspotModel);
	}
	
	/**
	 * Sets the data of the currently selected list item to 
	 * according text fields
	 * @param evt
	 */
	private void listHotspotsValueChanged(ListSelectionEvent evt) {
		// find the hotspot object that is corresponding to 
		// the selected list item
		String itemName = (String)this.listHotspots.getSelectedValue();
		final Hotspot selectedHotspot = this.findHotspot(itemName);
		
		EventQueue.invokeLater(new Runnable()
		{
			public void run()
			{
				textHotspotName.setText(selectedHotspot.getName());
				textHotspotBshName.setText(selectedHotspot.getBshName());
				textPosX.setText(selectedHotspot.getX());
				textPosY.setText(selectedHotspot.getY());
				textWidth.setText(selectedHotspot.getWidth());
				textHeight.setText(selectedHotspot.getHeight());
			}
		});	
	}
	
	/**
	 * Helper method to find the corresponding hotspot to the specified 
	 * name
	 * @param name name of the hotspot to find
	 * @return hotspot with the specified name
	 */
	private Hotspot findHotspot(String name)
	{
		for(Hotspot hs : this.hotspots)
		{
			if(hs.getName().equals(name)) return hs;
		}
		
		return null;
	}


}
