package gameaction;

import gameobjects.characters.AbstractCharacterSprite;

/**
 * This class can be used to put the playing of a sampled sound
 * file into the gameactions queue. After the sound starts playing
 * the next game action(s) will be executed parallel to the playing of
 * the sound file.
 * <b>Note: </b>If you would like to stop executing the following game
 * actions while the sound is playing use the PlaySoundExclusive game
 * action
 * @see gameaction.PlaySoundExclusive
 * @author Frank Bruns
 *
 */
public class PlaySound extends AbstractGameAction
{
	private String filePath = "no file path yet";
	
	/**
	 * Creates a new game action to play a sound parallel to the following
	 * game actions in the queue
	 * @param c character by whose current game location the sound
	 * is played 
	 * @param filePath path+filename to sound file
	 */
	public PlaySound(AbstractCharacterSprite c, String filePath)
	{
		super(c);
		this.filePath = filePath;
	}
	
	@Override
	public void update(long elapsedTime)
	{
		this.character.getGameLocation().playSound(this.filePath);
		this.character.getGameActionScheduler().removeFirst();
	}

}
