package gameaction;

import com.golden.gamedev.engine.BaseAudioRenderer;

import gameobjects.characters.AbstractCharacterSprite;

/**
 * This class can be used to put the playing of a sampled sound
 * file into the gameactions queue. After the sound starts playing
 * the next game action(s) will <b>not</b> be executed until the playing
 * of this sound file is complete.
 * <b>Note: </b>If you would like to play the sound file and execute
 * the following game actions while the sound is playing use 
 * the PlaySound game action
 * @see gameaction.PlaySound
 * @author Frank Bruns
 *
 */
public class PlaySoundExclusive extends AbstractGameAction
{
	private String filePath = "no file path yet";
	private boolean firstLoop = true;
	
	/**
	 * Creates a new game action to play a sound causing the following
	 * game actions to be suspended until the sound has been finished
	 * @param c character by whose current game location the sound
	 * is played 
	 * @param filePath path+filename to sound file
	 */
	public PlaySoundExclusive(AbstractCharacterSprite c, String filePath)
	{
		super(c);
		this.filePath = filePath;
	}

	@Override
	public void update(long elapsedTime)
	{
		if(this.firstLoop == true)
		{
			this.character.getGameLocation().playSound(this.filePath);
			this.firstLoop = false;
		}
		
		// remove the game action after sound has ended to allow processing
		// of the further game actions
		if(this.character.getGameLocation().getSoundRenderer().getAudioRenderer(this.filePath).getStatus() == BaseAudioRenderer.END_OF_SOUND)
		{
			this.character.getGameLocation().getSoundRenderer().getAudioRenderer(this.filePath).stop();
			this.character.getGameActionScheduler().removeFirst();
		}
	}

}
