package speech;

import java.awt.Graphics2D;
import java.io.Serializable;
import java.util.LinkedList;

/**
 * This class is used to schedule the rendering of sentences
 * @author Frank Bruns
 *
 */
public class SentenceScheduler implements Serializable
{
	private LinkedList<Sentence> sentences = null;
	
	public SentenceScheduler()
	{
		this.sentences = new LinkedList<Sentence>();
	}
	
	/**
	 * Adds a sentence object to the sentence scheduler
	 * @param s the sentece to add to the scheduler
	 */
	public void add(Sentence s)
	{
		this.sentences.add(s);
	}
	
	/**
	 * Removes every sentence from the queue
	 */
	public void clear()
	{
		this.sentences.clear();
	}
	
	/**
	 * Returns the sentences in the sentece scheduler
	 * @return list of sentences in the schedeler
	 */
	public LinkedList<Sentence> getSentences()
	{
		return this.sentences;
	}
	
	/**
	 * Updates the sentence scheduler. This calls the update method of
	 * the first sentence in the queue and removes that sentence from
	 * the queue, if it has been spoken
	 * @param elapsedTime time between two frames
	 */
	public void update(long elapsedTime)
	{
		if(this.sentences.isEmpty() == false)
		if(this.sentences.getFirst().isCurrentlySpoken() == true)
		{
			this.sentences.getFirst().update(elapsedTime);
		}
		else this.sentences.removeFirst();
	}
	
	/**
	 * Calls the render method of the first sentence in the queue
	 * @param g
	 */
	public void render(Graphics2D g)
	{
		if(this.sentences.isEmpty() == false)
		this.sentences.getFirst().render(g);
	}
}
