package util;

import java.io.*;
import java.util.*;

/**
 * This class can be used to instanciate an object for findng files 
 * of certain file extensions in a specified directory and all its
 * subdirectories
 * @author Frank Bruns, but the basics of the code originate from the 
 * book "Java ist auch eine Insel" by Christian Ullenboom
 *
 */
public class FileFinder
{
	public List<File> files = new ArrayList<File>();

	/**
	 * Creates a new object of this class with the specified parameter.
	 * @param startDirectory diretory to start in looking for files
	 * @param ext file extension to look for, e.g. ".txt" or ".bsh"
	 */
	public FileFinder(String startDirectory, String ext)
	{
		Stack<File> directories = new Stack<File>();
		File startDir = new File(startDirectory);
		if (startDir.isDirectory()) directories.push(startDir);
		while (directories.size() > 0)
		{
			for(File file : directories.pop().listFiles())
			{
				if(file.isDirectory()) directories.push(file);
				else if(match(file.getName(), ext)) this.files.add(file);
			}
		}
	}

	/**
	 * Returns a list of found files
	 * @return list of found files
	 */
	public List<File> getFoundFiles()
	{
		return this.files;
	}
	
	/**
	 * Returns the absolute file pathes of every found file 
	 * @return String array of absolute file pathes
	 */
	public String[] getFoundFilePathes()
	{
		String filePathes[] = new String[this.files.size()];
		for(int i=0; i<this.files.size(); i++)
		{
			filePathes[i] = this.files.get(i).getAbsolutePath();
		}
		
		return filePathes;
	}

	/**
	 * Checks if a filename has one of the specified extension 
	 * @param filename filename to check for the extension
	 * @param extension file extension, e.g. ".java" 
	 * @return
	 */
	private boolean match(String filename, String extension)
	{

		if(filename.length() >= extension.length()
				&& filename.substring(filename.length() - extension.length(), filename.length())
						.equalsIgnoreCase(extension))
		{
			return true;
		}
		
		return false;
	}
}
