package cursor;

import java.awt.Graphics2D;
import java.io.Serializable;
import java.util.HashMap;
import com.golden.gamedev.engine.BaseInput;

/**
 * This class represents a cursor manager that provides the different cursors
 * for the game.
 * @author Frank Bruns
 *
 */
public class CursorManager
{
	private static String currentCursor = "";
	
	private CursorManager() 
	{
		// no instanciation possible ;-)
	}
	
	private static HashMap<String, GameCursor> cursorPool = new HashMap<String, GameCursor>();
	
	/**
	 * Adds a new game cursor to the cursor pool with the specified parameters
	 * @param cursor game cursor to add to the cursor pool
	 */
	public static void addCursor(GameCursor cursor)
	{
		//Cursor cursor = Toolkit.getDefaultToolkit().createCustomCursor(icon, hotspot, constant);
		cursorPool.put(cursor.getConstant(), cursor);		
	}
	
	/**
	 * Returns the cursor refering to the specified String constant
	 * @param constant use a constant from the Cursors class --> Cursors.TALK
	 * @return cursor refering to the specified constant
	 */
	public static GameCursor getCursor(String constant)
	{
		return cursorPool.get(constant);
	}
	
	/**
	 * Sets the mouse pointer to the specified cursor
	 * @param constant constant refering to the cursor
	 */
	public static void setCursor(String constant) 
	{
		currentCursor = constant;
    }
	
	/**
	 * Returns the current game cursor
	 * @return current game cursor
	 */
	public static GameCursor getCurrentCursor()
	{
		return cursorPool.get(currentCursor);
	}
	
	/**
	 * Renders the current game cursor sprite
	 * @param g
	 * @param bsInput
	 */
	public static void render(Graphics2D g, BaseInput bsInput)
	{
		cursorPool.get(currentCursor).render(g,bsInput.getMouseX(),bsInput.getMouseY());
	}
}
