package editor.model;

/**
 * This class will be used by the gui to store information about an exit
 * created with the editor
 * @author Frank Bruns
 *
 */
public class Exit
{
	private String name = "";
	private String bshName = "";
	private String x = "";
	private String y = "";
	private String width = "";
	private String height = "";
	private String newX = "";
	private String newY = "";
	private String destination = "";
	
	/**
	 * Creates an exit object for data storage purposes for the editor
	 * @param name exit name
	 * @param bshName exit beanshell name
	 * @param x x coordinate
	 * @param y y coordinate
	 * @param width exit width
	 * @param height exit height
	 * @param newX new x coordiate after using the exit
	 * @param newY new y coordiate after using the exit
	 * @param destination destination game location name
	 */
	public Exit(String name, String bshName, String x, String y, 
			String width, String height, String newX, String newY, 
			String destination)
	{
		this.name = name;
		this.bshName = bshName;
		this.x = x;
		this.y = y;
		this.width = width;
		this.height = height;
		this.newX = newX;
		this.newY = newY;
		this.destination = destination;
	}

	/**
	 * Returns the beanshell name
	 * @return beanshell name
	 */
	public String getBshName()
	{
		return bshName;
	}

	/**
	 * Returns the name of the destination location
	 * @return name of the destination location
	 */
	public String getDestination()
	{
		return destination;
	}

	/**
	 * Returns the height
	 * @return height
	 */
	public String getHeight()
	{
		return height;
	}

	/**
	 * Returns the name
	 * @return name
	 */
	public String getName()
	{
		return name;
	}

	/**
	 * Returns the x coordinate of the character after useing the exit
	 * @return x coordinate of the character after useing the exit
	 */
	public String getNewX()
	{
		return newX;
	}

	/**
	 * Returns the y coordinate of the character after useing the exit
	 * @return y coordinate of the character after useing the exit
	 */
	public String getNewY()
	{
		return newY;
	}

	/**
	 * Returns the width
	 * @return width
	 */
	public String getWidth()
	{
		return width;
	}

	/**
	 * Returns the x coordinate
	 * @return x coordinate
	 */
	public String getX()
	{
		return x;
	}

	/**
	 * Returns the y coordinate
	 * @return y coordinate
	 */
	public String getY()
	{
		return y;
	}
}
