package gameaction;

import java.io.Serializable;

import gameobjects.characters.AbstractCharacterSprite;
/**
 * An abstract game action that contains everything which all derived
 * specialized game actions have in common
 * @author Frank Bruns
 *
 */
public abstract class AbstractGameAction implements Serializable
{
	protected AbstractCharacterSprite character = null;
	protected boolean secondMethodCall = false;
	
	/**
	 * Creates a new game action
	 * @param c character that performs the game action
	 */
	public AbstractGameAction(AbstractCharacterSprite c)
	{
		this.character = c;
	}
	
	/**
	 * Returns the character that performs the game action
	 * @return character that performs the game action
	 */
	public AbstractCharacterSprite getCharacter()
	{
		return this.character;
	}
	
	/**
	 * Determines, if the update() method of this game action has
	 * been called more than once
	 * @return at least second call of update()? --> true=yes, false=no
	 */
	public boolean isSecondMethodCall()
	{
		return this.secondMethodCall;
	}
	
	/**
	 * Updates the game action
	 * @param elapsedTime time between two frames
	 */
	public abstract void update(long elapsedTime);
}
