package gameaction;

import java.awt.Graphics2D;

import state.GameState;
import location.GameLocation;
import gameobjects.characters.AbstractCharacterSprite;
import gameobjects.characters.Player;

public class CutSceneStart extends AbstractGameAction
{
	private boolean  secondMethodCall = false;
	private GameLocation location = null;
	private String musicPath = null;
	
	/**
	 * Creates a new cutscene start game action
	 * @param c character on the current location (usually player)
	 * @param location location to switch to during cutscene
	 */
	public CutSceneStart(AbstractCharacterSprite c, GameLocation location)
	{
		super(c);
		this.location = location;
	}
	
	/**
	 * Creates a new cutscene start game action considering a special
	 * background music during cutscene 
	 * @param c character on the current location (usually player)
	 * @param location location to switch to during cutscene
	 * @param musicPath path+filename to cutscene background music
	 */
	public CutSceneStart(AbstractCharacterSprite c, GameLocation location, String musicPath)
	{
		super(c);
		this.location = location;
		this.musicPath = musicPath;
	}
	
	@Override
	public void update(long elapsedTime)
	{	
		// to prevent some a behaviour I do not understand right now
		// the code must get processed after the second call of
		// the update method and not at the first call
		if(this.secondMethodCall == true)
		{
			this.character.getGameLocation().setActive(false);
			this.location.setActive(true);
			GameState.setState(GameState.CUTSCENE);						
			
			// after the operations are performed this game action
			// can be removed from the queue
			this.character.getGameActionScheduler().removeFirst();
		}
		else
		{
			GameState.setState(GameState.TRANSITION_TO_CUTSCENE);
			this.secondMethodCall = true;
			if(this.musicPath != null
					&& this.location.getMusicFileName().equals(this.musicPath) == false)
				this.location.playMusic(this.musicPath, true);
		}
	}

	/**
	 * Renders a black screen for the first update() loop.
	 * @param g
	 */
	public void render(Graphics2D g)
	{
		if(this.secondMethodCall == false)
			g.fillRect(0, 0, 1024, 768);
	}
}
