package gameaction;

import gameobjects.characters.AbstractCharacterSprite;

/**
 * This game action can be used to run an animation sequence
 * specified by an image containing the sequence
 * @author Frank Bruns
 *
 */
public class RunAnimation extends AbstractGameAction
{
	private String animImgPath = "no path yet";
	private int numRepeats = 1;
	private boolean reachedLastFrame = false;
	long timeForLastAnimFrame = 0L;
	
	/**
	 * Creates a new game action for running an animation
	 * @param c character to use the animation for
	 * @param animImgPath path+filename to the anim sequence image
	 * @param rows number of rows in the anim sequence image
	 * @param picsPerRow number of pics per row of the anim image
	 */
	public RunAnimation(AbstractCharacterSprite c, String animImgPath, int rows, int picsPerRow)
	{
		super(c);
		this.animImgPath = animImgPath;
		this.character.getAnimPool().add(this.animImgPath, this.character.getBsLoader().getImages(this.animImgPath, picsPerRow, rows));
	}
	
	
	/**
	 * Creates a new game action for running an animation
	 * @param c character to use the animation for
	 * @param animImgPath path+filename to the anim sequence image
	 * @param rows number of rows in the anim sequence image
	 * @param picsPerRow number of pics per row of the anim image
	 * @param numRepeats number of times the animation ought to be
	 * played in immediate repetition
	 */
	public RunAnimation(AbstractCharacterSprite c, String animImgPath, int rows, int picsPerRow, int numRepeats)
	{
		super(c);
		this.animImgPath = animImgPath;
		this.numRepeats = numRepeats;
		this.character.getAnimPool().add(this.animImgPath, this.character.getBsLoader().getImages(this.animImgPath, picsPerRow, rows));
	}

	@Override
	public void update(long elapsedTime)
	{		
		if(this.character.getAnimScheduler().getCurrAnimName().equals(this.animImgPath) == false)
		{
			this.character.getAnimScheduler().clear();
			this.character.getAnimScheduler().add(this.animImgPath);
			this.character.getAnimScheduler().next();
		}
		
		if(this.reachedLastFrame == false
				&& this.character.getAnimScheduler().getCurrAnimName().equals(this.animImgPath)
				&& this.character.getFrame() == this.character.getFinishAnimationFrame())
		{		
			this.reachedLastFrame = true;
			this.timeForLastAnimFrame = this.character.getAnimationTimer().getDelay();
		}
		
		// clear the animation only after the last frame has been
		// displayed the amount time that was assigned by the
		// animation timer
		if(this.reachedLastFrame == true)
		{
			if(this.timeForLastAnimFrame <= 0L)
			{
				this.character.getAnimScheduler().clear();							
				this.character.getGameActionScheduler().removeFirst();
				
				String nextAnimName = this.character.getAnimScheduler().getNextAnimName(); 
				
				// remove the animation from the pool again to
				// save memory
				if(nextAnimName != null 
						&& nextAnimName.equals(this.animImgPath) == false)
				{
					this.character.getAnimPool().remove(this.animImgPath);
				}
			}
			else this.timeForLastAnimFrame -= elapsedTime;
		}
	}
	
}
