package path;

import java.awt.Point;
import java.util.LinkedList;

/**
 * This class represents a path. A path is a number of coordinates that get
 * travelled sequencially.
 * @author Frank Bruns
 *
 */
public class Path
{
	LinkedList<Point> path = null;
	Point previousPoint = null;
	
	public Path()
	{
		this.path = new LinkedList<Point>();
	}
	
	/**
	 * Adds a point to the path
	 * @param x x coordinate
	 * @param y y coordinate
	 */
	public void addPoint(double x, double y)
	{
		this.path.add(new Point((int)x,(int)y));
	}
	
	/**
	 * Returns the current point of the path. Returns null if no point
	 * is available
	 * @return current point of the path
	 */
	public Point getCurrentPoint()
	{
		if(this.path.isEmpty() == false) return this.path.getFirst();
		else return null;
	}
	
	/**
	 * Returns the next point in the path. If there is no next
	 * point the current point will be returned
	 * @return next point in the path, if available
	 */
	public Point getNextPoint()
	{
		if(this.path.size() > 1) return this.path.get(1);
		else return this.path.getFirst();
	}
	
	/**
	 * Returns the point previous to the current one of the path if there
	 * exits one, otherwise null is returned
	 * @return point previous to the current one of the path
	 */
	public Point getPreviousPoint()
	{
		if(this.previousPoint != null) return this.previousPoint;
		else return null;
	}
	
	/**
	 * Returns the list of points of the path
	 * @return list of points of the path
	 */
	public LinkedList<Point> getPoints()
	{
		return this.path;
	}
	
	/**
	 * Sets the next point of the path as the active one
	 */
	public void next()
	{
		if(this.path.isEmpty() == false)
		{
			this.previousPoint = this.path.getFirst();
			this.path.removeFirst();		
		}
	}
}
