package speech;

import java.io.Serializable;

import gameaction.Talk;
import gameobjects.characters.Player;

/**
 * This class represents a branch of a dialog
 * @author Frank Bruns
 *
 */
public class DialogBranch implements Serializable
{
	private int id = -1;
	private String assocQuestion = "no associated question yet";
	private Talk talkAction = null; 
	
	/** 
	 * boolean controls whether the branch can be shown in the
	 * question selection area
	 */	
	private boolean exclude = false;
	
	/**
	 * Creates a new dialog branch with the specified talk action.
	 * Make sure that the talk action is already filled with all the
	 * sentences when you pass it over as an parameter
	 * @param id id of the dialog branch
	 * @param talkAction talk action for the dialog branch
	 */
	public DialogBranch(int id, String question, Talk talkAction)
	{
		this.id = id;
		this.assocQuestion = question;
		this.talkAction = talkAction;
	}
	
	/**
	 * Returns the id of the dialog branch
	 * @return id of the dialog branch
	 */
	public int getID()
	{
		return this.id;
	}
	
	/**
	 * Returns whether the dialog branch is to be excluded from
	 * showing in the question selection area
	 * @return is to be excluded? --> true=yes, false=no 
	 */
	public boolean isExcluded()
	{
		return this.exclude;
	}
	
	/**
	 * Returns whether the dialog branch is to be excluded from
	 * showing in the question selection area
	 * @param exclude exclude from selection area? --> true=yes, false=no 
	 */
	public void setExclude(boolean exclude)
	{
		this.exclude = exclude;
	}
	
	/**
	 * Returns the question that is associated to this dialog branch.
	 * @return question that is associated to this dialog branch
	 */
	public String getAssociatedQuestion()
	{
		return this.assocQuestion;
	}
	
	/**
	 * Returns the talk action of the dialog branch
	 * @return talk action of the dialog branch
	 */
	public Talk getTalkAction()
	{
		return this.talkAction;
	}
}
