package state;

import java.io.Serializable;

/**
 * This class manages various game states of the game
 * @author Frank Bruns
 *
 */
public class GameState  implements Serializable
{
	/** the normal game mode */
	public static final int NORMAL = 0;
	/** state to signal the player is walking to a dialog */
	public static final int WALKING_TO_DIALOG = 1;
	/** state when showing the question selection area */
	public static final int DIALOG_SELECTION = 2;
	/** game state when running a dialog */
	public static final int DIALOG = 3;
	/** game state to signal that no user will be processed */
	public static final int NO_INPUT_PROCESSING = 4;
	/** game state to signal running of cutscene */
	public static final int CUTSCENE = 5;
	/** 
	 * game state to describe that a cutscene will start
	 * the next frame. In this gamestate only a black screen 
	 * should be drawn
	 */ 
	public static final int TRANSITION_TO_CUTSCENE = 6;
	/** 
	 * game state to describe that a cutscene will stop
	 * the next frame. In this gamestate only a black screen 
	 * should be drawn
	 */ 
	public static final int TRANSITION_FROM_CUTSCENE = 7;
	/** game state for running the intro */
	public static final int INTRO_MODE = 8;
	
	private static int currentState = NORMAL;
	
	/**
	 * Sets the current game state to the specified parameter,
	 * for example GameState.DIALOG
	 * @param state new game state 
	 */
	public static void setState(int state)
	{
		currentState = state;
	}
	
	/**
	 * Returns the current set game state
	 * @return current game state that is set
	 */
	public static int getState()
	{
		return currentState;
	}
	
	/**
	 * Determins whether the current gamestate is equal to the specified one 
	 * @param state the state to compare for equality
	 * @return is state equal to current state? --> true=yes, false=no
	 */
	public static boolean equals(int state)
	{
		return currentState == state;
	}
}
