package xml;

import java.io.FileWriter;
import java.io.IOException;
import java.util.Vector;

import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;
import org.dom4j.io.OutputFormat;
import org.dom4j.io.XMLWriter;

import editor.model.BasicGameLocation;
import editor.model.Exit;
import editor.model.Hotspot;

/**
 * This class can be used to export the information for a game location
 * that has been specified in the edtor to the according XML file
 * @author Frank Bruns
 *
 */
public class LocationExporter
{
	private Document document = null;
	private String fileName = "";
	
	public LocationExporter(String fileName)
	{		
		this.fileName = fileName;
	}
	
	public void exportToXML(BasicGameLocation bgl, Vector<Exit> exits, Vector<Hotspot> hs)	
	{
		System.out.println("Trying to generate xml file");
		this.document = DocumentHelper.createDocument();
		
		Element root = document.addElement( "location" );

        Element name = root.addElement("name");
        name.addText(bgl.getLocationName());
        
        Element bshName = root.addElement("bshname");
        bshName.addText(bgl.getLocationBshName());
		
        Element script = root.addElement("script");
        script.addText(bgl.getScriptFileName());
        
        Element bgImg = root.addElement("bgimage");
        bgImg.addText(bgl.getBGImageFileName());
        
        Element bgMusic = root.addElement("bgmusic");
        bgMusic.addText(bgl.getMusicFileName());
        
        for(Exit e : exits)
        {
        	Element exit = root.addElement("exit");
        	
        	Element exitName = exit.addElement("name");
        	exitName.addText(e.getName());
        	
        	Element exitBshName = exit.addElement("bshname");
        	exitBshName.addText(e.getBshName());
        	
        	Element exitPosX = exit.addElement("x");
        	exitPosX.addText(e.getX());
        	
        	Element exitPosY = exit.addElement("y");
        	exitPosY.addText(e.getY());
        	
        	Element exitWidth = exit.addElement("width");
        	exitWidth.addText(e.getWidth());
        	
        	Element exitHeight = exit.addElement("height");
        	exitHeight.addText(e.getHeight());
        	
        	Element exitNewX = exit.addElement("newx");
        	exitNewX.addText(e.getNewX());
        	
        	Element exitNewY = exit.addElement("newy");
        	exitNewY.addText(e.getNewY());
        	
        	Element exitDest = exit.addElement("destination");
        	exitDest.addText(e.getDestination());
        }
        
        for(Hotspot h : hs)
        {
        	Element hot = root.addElement("hotspot");
        	
        	Element hsName = hot.addElement("name");
        	hsName.addText(h.getName());
        	
        	Element hsBshName = hot.addElement("bshname");
        	hsBshName.addText(h.getBshName());
        	
        	Element hsPosX = hot.addElement("x");
        	hsPosX.addText(h.getX());
        	
        	Element hsPosY = hot.addElement("y");
        	hsPosY.addText(h.getY());
        	
        	Element hsWidth = hot.addElement("width");
        	hsWidth.addText(h.getWidth());
        	
        	Element hsHeight = hot.addElement("height");
        	hsHeight.addText(h.getHeight());
        }
        
        
        XMLWriter writer = null;
		try
		{
			OutputFormat format = OutputFormat.createPrettyPrint();
			writer = new XMLWriter(
					new FileWriter(this.fileName),format);
			writer.write(document);
	        writer.close();
	        System.out.println("XML file successfully created.");
		}
		catch (IOException e)
		{
			System.out.println("Error while generating xml file");
			e.printStackTrace();
		}        
	}
	
}
